<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Web.AtomPub

Windows Runtime (WinRT) APIs for for the `Windows.Web.AtomPub` namespace.

This package provides the `winrt.windows.web.atompub` module.
